OpenNebula Python Bindings
==================================

Description
-----------

PyOne is an implementation of Open Nebula XML-RPC bindings in Python. It has been integrated into upstream OpenNebula release cycles from `here <https://github.com/OpenNebula/addon-pyone>`_.
